==> org.apache.httpcomponents.core5.httpcore5.source_5.1.2.v20211217-1500.jar: org/apache/hc/core5/http/io/HttpClientResponseHandler.java <==
/*
 * ====================================================================
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 *
 */
package org.apache.hc.core5.http.io;

import java.io.IOException;

import org.apache.hc.core5.http.ClassicHttpResponse;
import org.apache.hc.core5.http.HttpException;

/**
 * Handler that encapsulates the process of generating a response object
 * from a {@link ClassicHttpResponse}.
 *
 *
 * @since 4.0
 */
public interface HttpClientResponseHandler<T> {

    /**
     * Processes an {@link ClassicHttpResponse} and returns some value
     * corresponding to that response.
     *
     * @param response The response to process
     * @return A value determined by the response
     *
     * @throws IOException in case of a problem or the connection was aborted
     */
    T handleResponse(ClassicHttpResponse response) throws HttpException, IOException;

}

==> org.apache.httpcomponents.core5.httpcore5.source_5.3.6.v20250921-0900.jar: org/apache/hc/core5/http/io/HttpClientResponseHandler.java <==
/*
 * ====================================================================
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 *
 */
package org.apache.hc.core5.http.io;

import java.io.IOException;

import org.apache.hc.core5.http.ClassicHttpResponse;
import org.apache.hc.core5.http.HttpException;

/**
 * Handler that encapsulates the process of generating a response object
 * from a {@link ClassicHttpResponse}.
 *
 * @param <T> the type of the response.
 * @since 4.0
 */
@FunctionalInterface
public interface HttpClientResponseHandler<T> {

    /**
     * Processes an {@link ClassicHttpResponse} and returns some value
     * corresponding to that response.
     *
     * @param response The response to process
     * @return A value determined by the response
     *
     * @throws IOException in case of a problem or the connection was aborted
     * @throws HttpException in case of an HTTP protocol violation.
     */
    T handleResponse(ClassicHttpResponse response) throws HttpException, IOException;

}
